@@ -7,7 +7,7 @@ from python_pachyderm.service import Service
 from .util import commit_from
 
 
-BUFFER_SIZE = 20 * 1024 * 1024
+BUFFER_SIZE = 19 * 1024 * 1024
 
 
 def put_file_from_filelike(commit, path, value, delimiter=None, target_file_datums=None, target_file_bytes=None,
@@ -69,6 +69,69 @@ def put_file_from_bytestring(commit, path, value, delimiter=None, target_file_da
         )
 
 
+class PFSFile:
+    """
+    The contents of a file stored in PFS. You can treat these as either
+    file-like objects, like so:
+
+    ```
+    source_file = client.get_file("montage/master", "/montage.png")
+    with open("montage.png", "wb") as dest_file:
+        shutil.copyfileobj(source_file, dest_file)
+    ```
+
+    Or as an iterator of bytes, like so:
+
+    ```
+    source_file = client.get_file("montage/master", "/montage.png")
+    with open("montage.png", "wb") as dest_file:
+        for chunk in source_file:
+            dest_file.write(chunk)
+    ```
+    """
+
+    def __init__(self, res):
+        self.res = res
+        self.buf = []
+
+    def __iter__(self):
+        return self
+
+    def __next__(self):
+        return next(self.res).value
+
+    def close(self):
+        self.res.cancel()
+
+    def read(self, size=-1):
+        if self.res.cancelled():
+            return b""
+
+        buf = []
+        remaining = size if size >= 0 else 2 ** 32
+
+        if self.buf:
+            buf.append(self.buf[:remaining])
+            self.buf = self.buf[remaining:]
+            remaining -= len(buf[-1])
+
+        try:
+            while remaining > 0:
+                b = next(self)
+
+                if len(b) > remaining:
+                    buf.append(b[:remaining])
+                    self.buf = b[remaining:]
+                else:
+                    buf.append(b)
+
+                remaining -= len(buf[-1])
+        except StopIteration:
+            pass
+
+        return b"".join(buf)
+
+
 class PFSMixin:
     def create_repo(self, repo_name, description=None, update=None):
         """
@@ -374,8 +437,8 @@ class PFSMixin:
             force=force,
         )
 
-    def put_file_bytes(self, commit, path, value, delimiter=None,
-                       target_file_datums=None, target_file_bytes=None, overwrite_index=None, header_records=None):
+    def put_file_bytes(self, commit, path, value, delimiter=None, target_file_datums=None, target_file_bytes=None,
+                       overwrite_index=None, header_records=None):
         """
         Uploads a binary bytes array as file(s) in a certain path.
 
@@ -510,7 +573,8 @@ class PFSMixin:
 
     def get_file(self, commit, path, offset_bytes=None, size_bytes=None):
         """
-        Returns an iterator of the contents of a file at a specific commit.
+        Returns a `PFSFile` object, containing the contents of a file stored
+        in PFS.
 
         Params:
 
@@ -530,8 +594,7 @@ class PFSMixin:
             offset_bytes=offset_bytes,
             size_bytes=size_bytes,
         )
-        for item in res:
-            yield item.value
+        return PFSFile(res)
 
     def inspect_file(self, commit, path):
         """
